# PLANS.md

## Goal

## Scope / non-goals

## Invariants and contracts to preserve

## Files / layers likely to change

## Ordered steps
1.

## Validation plan

## Rollback / recovery notes

## Risks / blockers

## Definition of done
